@@ -7,7 +7,6 @@ import io
 import os
 import re
 import shutil
-import socket
 import subprocess
 import tempfile
 import threading
@@ -56,6 +55,7 @@ from ansys.mapdl.core.common_grpc import (
 from ansys.mapdl.core.errors import MapdlExitedError, MapdlRuntimeError, protect_grpc
 from ansys.mapdl.core.mapdl import _MapdlCore
 from ansys.mapdl.core.misc import (
+    check_valid_ip,
     last_created,
     random_string,
     run_as_prep7,
@@ -161,13 +161,6 @@ class RepeatingTimer(threading.Timer):
             self.finished.wait(self.interval)
 
 
-def check_valid_ip(ip):
-    """Check for valid IP address"""
-    if ip != "localhost":
-        ip = ip.replace('"', "").replace("'", "")
-        socket.inet_aton(ip)
-
-
 class MapdlGrpc(_MapdlCore):
     """This class connects to a GRPC MAPDL server and allows commands
     to be passed to a persistent session.
@@ -380,7 +373,7 @@ class MapdlGrpc(_MapdlCore):
 
         if not connected:
             raise IOError(
-                f"Unable to connect to MAPDL gRPC instance at {self._target_str}"
+                f"Unable to connect to MAPDL gRPC instance at {self._channel_str}"
             )
 
     @property
